@@ -15,18 +15,11 @@ API for Web Map Service (WMS) methods and metadata.
 Currently supports only version 1.1.1 of the WMS protocol.
 """
 
-from __future__ import (absolute_import, division, print_function)
-
 import cgi
-try:                    # Python 3
-    from urllib.parse import urlencode
-except ImportError:     # Python 2
-    from urllib import urlencode
+from urllib.parse import urlencode
 
 import warnings
 
-import six
-
 from owslib.etree import etree
 from owslib.util import (openURL, testXMLValue, extract_xml_list,
                          xmltag_split, OrderedDict, ServiceException,
@@ -38,6 +31,7 @@ from owslib.namespaces import Namespaces
 
 n = Namespaces()
 
+
 class CapabilitiesError(Exception):
     pass
 
@@ -159,8 +153,8 @@ class WebMapService_1_1_1(object):
         return u
 
     def __build_getmap_request(self, layers=None, styles=None, srs=None, bbox=None,
-               format=None, size=None, time=None, transparent=False,
-               bgcolor=None, exceptions=None, **kwargs):
+                               format=None, size=None, time=None, transparent=False,
+                               bgcolor=None, exceptions=None, **kwargs):
 
         request = {'service': 'WMS', 'version': self.version, 'request': 'GetMap'}
 
@@ -189,7 +183,7 @@ class WebMapService_1_1_1(object):
 
         if kwargs:
             for kw in kwargs:
-                request[kw]=kwargs[kw]
+                request[kw] = kwargs[kw]
         return request
 
     def getmap(self, layers=None, styles=None, srs=None, bbox=None,
@@ -242,7 +236,8 @@ class WebMapService_1_1_1(object):
 
         """
         try:
-            base_url = next((m.get('url') for m in self.getOperationByName('GetMap').methods if m.get('type').lower() == method.lower()))
+            base_url = next((m.get('url') for m in self.getOperationByName('GetMap').methods
+                            if m.get('type').lower() == method.lower()))
         except StopIteration:
             base_url = self.url
         request = {'version': self.version, 'request': 'GetMap'}
@@ -264,13 +259,13 @@ class WebMapService_1_1_1(object):
 
         self.request = bind_url(base_url) + data
 
-        u = openURL(base_url, data, method, timeout=timeout or self.timeout, auth=self.auth)
+        u = openURL(base_url, data, method, timeout=timeout or self.timeout, auth=self.auth, headers=self.headers)
 
         # check for service exceptions, and return
         if u.info().get('Content-Type', '').split(';')[0] in ['application/vnd.ogc.se_xml']:
             se_xml = u.read()
             se_tree = etree.fromstring(se_xml)
-            err_message = six.text_type(se_tree.find('ServiceException').text).strip()
+            err_message = str(se_tree.find('ServiceException').text).strip()
             raise ServiceException(err_message)
         return u
 
@@ -294,7 +289,8 @@ class WebMapService_1_1_1(object):
                        **kwargs
                        ):
         try:
-            base_url = next((m.get('url') for m in self.getOperationByName('GetFeatureInfo').methods if m.get('type').lower() == method.lower()))
+            base_url = next((m.get('url') for m in self.getOperationByName('GetFeatureInfo').methods
+                            if m.get('type').lower() == method.lower()))
         except StopIteration:
             base_url = self.url
 
@@ -330,13 +326,13 @@ class WebMapService_1_1_1(object):
 
         self.request = bind_url(base_url) + data
 
-        u = openURL(base_url, data, method, timeout=timeout or self.timeout, auth=self.auth)
+        u = openURL(base_url, data, method, timeout=timeout or self.timeout, auth=self.auth, headers=self.headers)
 
         # check for service exceptions, and return
         if u.info()['Content-Type'] == 'application/vnd.ogc.se_xml':
             se_xml = u.read()
             se_tree = etree.fromstring(se_xml)
-            err_message = six.text_type(se_tree.find('ServiceException').text).strip()
+            err_message = str(se_tree.find('ServiceException').text).strip()
             raise ServiceException(err_message)
         return u
 
@@ -346,18 +342,19 @@ class WebMapService_1_1_1(object):
             xml = etree.tostring(self._capabilities)
         return xml
 
-    def getOperationByName(self, name): 
+    def getOperationByName(self, name):
         """Return a named content item."""
         for item in self.operations:
             if item.name == name:
                 return item
         raise KeyError("No operation named %s" % name)
 
+
 class ServiceIdentification(object):
     ''' Implements IServiceIdentificationMetadata '''
 
     def __init__(self, infoset, version):
-        self._root=infoset
+        self._root = infoset
         self.type = testXMLValue(self._root.find('Name'))
         self.version = version
         self.title = testXMLValue(self._root.find('Title'))
@@ -366,23 +363,24 @@ class ServiceIdentification(object):
         self.accessconstraints = testXMLValue(self._root.find('AccessConstraints'))
         self.fees = testXMLValue(self._root.find('Fees'))
 
+
 class ServiceProvider(object):
     ''' Implements IServiceProviderMetatdata '''
     def __init__(self, infoset):
-        self._root=infoset
-        name=self._root.find('ContactInformation/ContactPersonPrimary/ContactOrganization')
+        self._root = infoset
+        name = self._root.find('ContactInformation/ContactPersonPrimary/ContactOrganization')
         if name is not None:
-            self.name=name.text
+            self.name = name.text
         else:
-            self.name=None
+            self.name = None
         self.url = None
         online_resource = self._root.find('OnlineResource')
         if online_resource is not None:
             self.url = online_resource.attrib.get('{http://www.w3.org/1999/xlink}href', '')
-        #contact metadata
+        # contact metadata
         contact = self._root.find('ContactInformation')
-        ## sometimes there is a contact block that is empty, so make
-        ## sure there are children to parse
+        # sometimes there is a contact block that is empty, so make
+        # sure there are children to parse
         if contact is not None and contact[:] != []:
             self.contact = ContactMetadata(contact)
         else:
@@ -402,6 +400,7 @@ class ServiceProvider(object):
                 return item
         raise KeyError("No operation named %s" % name)
 
+
 class ContentMetadata(AbstractContentMetadata):
     """
     Abstraction for WMS layer metadata.
@@ -465,7 +464,7 @@ class ContentMetadata(AbstractContentMetadata):
         self.scaleHint = None
         if sh is not None:
             if 'min' in sh.attrib and 'max' in sh.attrib:
-                self.scaleHint = {'min': sh.attrib['min'], 'max': sh.attrib['max']} 
+                self.scaleHint = {'min': sh.attrib['min'], 'max': sh.attrib['max']}
 
         attribution = elem.find('Attribution')
         if attribution is not None:
@@ -473,11 +472,11 @@ class ContentMetadata(AbstractContentMetadata):
             title = attribution.find('Title')
             url = attribution.find('OnlineResource')
             logo = attribution.find('LogoURL')
-            if title is not None: 
+            if title is not None:
                 self.attribution['title'] = title.text
             if url is not None:
                 self.attribution['url'] = url.attrib['{http://www.w3.org/1999/xlink}href']
-            if logo is not None: 
+            if logo is not None:
                 self.attribution['logo_size'] = (int(logo.attrib['width']), int(logo.attrib['height']))
                 self.attribution['logo_url'] = logo.find('OnlineResource').attrib['{http://www.w3.org/1999/xlink}href']
 
@@ -503,62 +502,67 @@ class ContentMetadata(AbstractContentMetadata):
 
         # Look for SRS option attached to this layer
         if elem.find('SRS') is not None:
-            ## some servers found in the wild use a single SRS
-            ## tag containing a whitespace separated list of SRIDs
-            ## instead of several SRS tags. hence the inner loop
+            # some servers found in the wild use a single SRS
+            # tag containing a whitespace separated list of SRIDs
+            # instead of several SRS tags. hence the inner loop
             for srslist in [x.text for x in elem.findall('SRS')]:
                 if srslist:
                     for srs in srslist.split():
                         self.crsOptions.append(srs)
 
-        #Get rid of duplicate entries
+        # Get rid of duplicate entries
         self.crsOptions = list(set(self.crsOptions))
 
-        #Set self.crsOptions to None if the layer (and parents) had no SRS options
+        # Set self.crsOptions to None if the layer (and parents) had no SRS options
         if len(self.crsOptions) == 0:
-            #raise ValueError('%s no SRS available!?' % (elem,))
-            #Comment by D Lowe.
-            #Do not raise ValueError as it is possible that a layer is purely a parent layer and does not have SRS specified. Instead set crsOptions to None
+            # raise ValueError('%s no SRS available!?' % (elem,))
+            # Comment by D Lowe.
+            # Do not raise ValueError as it is possible that a layer is purely a parent layer and does
+            # not have SRS specified. Instead set crsOptions to None
             # Comment by Jachym:
             # Do not set it to None, but to [], which will make the code
             # work further. Fixed by anthonybaxter
             self.crsOptions = []
 
-        #Styles
+        # Styles
         self.styles = {}
 
-        #Copy any parent styles (they are inheritable properties)
+        # Copy any parent styles (they are inheritable properties)
         if self.parent:
             self.styles = self.parent.styles.copy()
 
-        #Get the styles for this layer (items with the same name are replaced)
+        # Get the styles for this layer (items with the same name are replaced)
         for s in elem.findall('Style'):
             name = s.find('Name')
             title = s.find('Title')
+            if name is None and title is None:
+                raise ValueError('%s missing name and title' % (s,))
             if name is None or title is None:
-                raise ValueError('%s missing name or title' % (s,))
-            style = { 'title' : title.text }
+                warnings.warn('%s missing name or title' % (s,))
+            title_ = title.text if title is not None else name.text
+            name_ = name.text if name is not None else title.text
+            style = {'title': title_}
             # legend url
             legend = s.find('LegendURL/OnlineResource')
             if legend is not None:
                 style['legend'] = legend.attrib['{http://www.w3.org/1999/xlink}href']
-            self.styles[name.text] = style
+            self.styles[name_] = style
 
         # keywords
         self.keywords = [f.text for f in elem.findall('KeywordList/Keyword')]
 
         # timepositions - times for which data is available.
-        self.timepositions=None
+        self.timepositions = None
         self.defaulttimeposition = None
         for extent in elem.findall('Extent'):
-            if extent.attrib.get("name").lower() =='time':
+            if extent.attrib.get("name").lower() == 'time':
                 if extent.text:
-                    self.timepositions=extent.text.split(',')
+                    self.timepositions = extent.text.split(',')
                     self.defaulttimeposition = extent.attrib.get("default")
                     break
 
         # Elevations - available vertical levels
-        self.elevations=None
+        self.elevations = None
         for extent in elem.findall('Extent'):
             if extent.attrib.get("name").lower() == 'elevation':
                 if extent.text:
@@ -579,9 +583,11 @@ class ContentMetadata(AbstractContentMetadata):
         self.dataUrls = []
         for m in elem.findall('DataURL'):
             dataUrl = {
-                'format': m.find('Format').text.strip(),
+                'format': testXMLValue(m.find('Format')),
                 'url': m.find('OnlineResource').attrib['{http://www.w3.org/1999/xlink}href']
             }
+            if dataUrl['format']:
+                dataUrl['format'] = dataUrl['format'].strip()
             self.dataUrls.append(dataUrl)
 
         self.layers = []
@@ -595,7 +601,7 @@ class ContentMetadata(AbstractContentMetadata):
                     and metadataUrl['format'].lower() in ['application/xml', 'text/xml']:  # download URL
                 try:
                     content = openURL(
-                        metadataUrl['url'], timeout=timeout, auth=self.auth)
+                        metadataUrl['url'], timeout=timeout, auth=self.auth, headers=self.headers)
                     doc = etree.fromstring(content.read())
 
                     if metadataUrl['type'] == 'FGDC':
@@ -606,7 +612,7 @@ class ContentMetadata(AbstractContentMetadata):
 
                     if metadataUrl['type'] == 'TC211':
                         mdelem = doc.find('.//' + nspath_eval('gmd:MD_Metadata', n.get_namespaces(['gmd']))) \
-                                 or doc.find('.//' + nspath_eval('gmi:MI_Metadata', n.get_namespaces(['gmi'])))
+                            or doc.find('.//' + nspath_eval('gmi:MI_Metadata', n.get_namespaces(['gmi'])))
                         if mdelem is not None:
                             metadataUrl['metadata'] = MD_Metadata(mdelem)
                             continue
@@ -641,7 +647,7 @@ class OperationMetadata:
         self.methods = []
         for verb in elem.findall('DCPType/HTTP/*'):
             url = verb.find('OnlineResource').attrib['{http://www.w3.org/1999/xlink}href']
-            self.methods.append({'type' : xmltag_split(verb.tag), 'url': url})
+            self.methods.append({'type': xmltag_split(verb.tag), 'url': url})
 
 
 class ContactMetadata:
@@ -664,24 +670,33 @@ class ContactMetadata:
         address = elem.find('ContactAddress')
         if address is not None:
             street = address.find('Address')
-            if street is not None: self.address = street.text
+            if street is not None:
+                self.address = street.text
 
             city = address.find('City')
-            if city is not None: self.city = city.text
+            if city is not None:
+                self.city = city.text
 
             region = address.find('StateOrProvince')
-            if region is not None: self.region = region.text
+            if region is not None:
+                self.region = region.text
 
             postcode = address.find('PostCode')
-            if postcode is not None: self.postcode = postcode.text
+            if postcode is not None:
+                self.postcode = postcode.text
 
             country = address.find('Country')
-            if country is not None: self.country = country.text
+            if country is not None:
+                self.country = country.text
 
         organization = elem.find('ContactPersonPrimary/ContactOrganization')
-        if organization is not None: self.organization = organization.text
-        else:self.organization = None
+        if organization is not None:
+            self.organization = organization.text
+        else:
+            self.organization = None
 
         position = elem.find('ContactPosition')
-        if position is not None: self.position = position.text
-        else: self.position = None
+        if position is not None:
+            self.position = position.text
+        else:
+            self.position = None
