@@ -6,20 +6,21 @@
 # Contact email: tomkralidis@gmail.com
 # =============================================================================
 
+from copy import deepcopy
 import json
 import logging
-from urllib.parse import urljoin
+from urllib.parse import urlencode, urljoin
 
 import requests
 import yaml
 
 from owslib import __version__
-from owslib.util import Authentication, http_get
+from owslib.util import Authentication, http_get, http_post
 
 LOGGER = logging.getLogger(__name__)
 
 REQUEST_HEADERS = {
-    'User-Agent': 'OWSLib {} (https://geopython.github.io/OWSLib)'.format(__version__)
+    'User-Agent': f'OWSLib {__version__} (https://geopython.github.io/OWSLib)'
 }
 
 
@@ -58,11 +59,11 @@ class API:
         self.auth = auth
 
         if json_ is not None:  # static JSON string
-            self.links = json.loads(json_)['links']
+            self.links = json.loads(json_).get('links', [])
             self.response = json_
         else:
             response = http_get(url, headers=self.headers, auth=self.auth).json()
-            self.links = response['links']
+            self.links = response.get('links', [])
             self.response = response
 
     def api(self) -> dict:
@@ -93,7 +94,7 @@ class API:
                     break
 
         if url is not None:
-            LOGGER.debug('Request: {}'.format(url))
+            LOGGER.debug(f'Request: {url}')
             response = http_get(url, headers=REQUEST_HEADERS, auth=self.auth)
             if openapi_format == openapi_json_mimetype:
                 content = response.json()
@@ -115,7 +116,7 @@ class API:
         path = 'conformance'
         return self._request(path)
 
-    def _build_url(self, path: str = None) -> str:
+    def _build_url(self, path: str = None, params: dict = {}) -> str:
         """
         helper function to build an OGC API URL
 
@@ -133,7 +134,10 @@ class API:
         else:
             url = urljoin(url, path)
 
-        LOGGER.debug('URL: {}'.format(url))
+        if params:
+            url = '?'.join([url, urlencode(params)])
+
+        LOGGER.debug(f'URL: {url}')
 
         return url
 
@@ -155,13 +159,20 @@ class API:
         url = self._build_url(path)
         self.request = url
 
-        LOGGER.debug('Request: {}'.format(url))
-        LOGGER.debug('Params: {}'.format(kwargs))
+        LOGGER.debug(f'Request: {url}')
+        LOGGER.debug(f'Params: {kwargs}')
 
-        response = http_get(url, headers=self.headers, auth=self.auth,
-                            params=kwargs)
+        if 'cql' not in kwargs:
+            response = http_get(url, headers=self.headers, auth=self.auth,
+                                params=kwargs)
+        else:
+            LOGGER.debug('CQL query detected')
+            kwargs2 = deepcopy(kwargs)
+            cql = kwargs2.pop('cql')
+            url2 = self._build_url(path, kwargs2)
+            response = http_post(url2, request=cql, auth=self.auth)
 
-        LOGGER.debug('URL: {}'.format(response.url))
+        LOGGER.debug(f'URL: {response.url}')
 
         if response.status_code != requests.codes.ok:
             raise RuntimeError(response.text)
@@ -200,7 +211,7 @@ class Collections(API):
         @returns: `dict` of feature collection metadata
         """
 
-        path = 'collections/{}'.format(collection_id)
+        path = f'collections/{collection_id}'
         return self._request(path)
 
     def collection_queryables(self, collection_id: str) -> dict:
@@ -213,5 +224,5 @@ class Collections(API):
         @returns: `dict` of feature collection queryables
         """
 
-        path = 'collections/{}/queryables'.format(collection_id)
+        path = f'collections/{collection_id}/queryables'
         return self._request(path)
